package net.lemnik.eodsql;

/**
 * Enumeration used by the {@link Update @Update} annotation to specify what to
 * do with keys generated by the database.
 *
 * @author jason
 * @see Update
 * @see AutoGeneratedKeys
 */
public enum GeneratedKeys {
    /**
     * Specifies that a normal {@link java.sql.Statement#executeUpdate} should be
     * performed.
     */
    NO_KEYS_RETURNED,
    /**
     * Specifies that the JDBC driver should return whatever keys it decides to. This
     * is the equivalent of
     * Statement.executeUpdate(String sql, Statement.RETURN_GENERATED_KEYS)
     */
    RETURNED_KEYS_DRIVER_DEFINED,
    /**
     * This specifies that the generated keys should be explicitly requested from
     * the JDBC driver by name. This is the equivalent of
     * Statement.executeUpdate(String sql, String [] colNames)
     */
    RETURNED_KEYS_COLUMNS_SPECIFIED,
    /**
     * <p>
     * Specifies that the the first column from of the generated keys should be
     * mapped as the AutoGeneratedKeys. Several JDBC drivers don't handle the returning
     * of more than one generated key, and often don't support returning the key with
     * it's real column name. This flag can be used to work around such drivers.
     * </p><p>
     * This option can also be used as an optimization when a non-composite auto-generated key
     * is being used (which is most of the time).
     * </p>
     *
     * @since 1.1
     */
    RETURNED_KEYS_FIRST_COLUMN
}
